=======
History
=======

0.2.15 (2023-06-17)
-------------------

* Fixing Non-ASCII character error by using avg read qual instead of the default value
* Added option -het to include heterozygous sites in the calculation of discordant rate.

0.1.1 (2021-01-07)
------------------

* First release on PyPI.
